# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_topic.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v4.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from ydb._grpc.v4.protos import ydb_scheme_pb2 as protos_dot_ydb__scheme__pb2
from ydb._grpc.v4.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2
from ydb._grpc.v4.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v4.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16protos/ydb_topic.proto\x12\tYdb.Topic\x1a\x1aprotos/ydb_operation.proto\x1a\x17protos/ydb_scheme.proto\x1a\x1dprotos/ydb_status_codes.proto\x1a\x1eprotos/ydb_issue_message.proto\x1a#protos/annotations/validation.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"7\n\x0fSupportedCodecs\x12$\n\x06\x63odecs\x18\x01 \x03(\x05\x42\x14\xb2\xe6*\n[1; 19999]\x9a\xe6*\x02\x18\x64\"*\n\x0cOffsetsRange\x12\r\n\x05start\x18\x01 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x03\"#\n\x12UpdateTokenRequest\x12\r\n\x05token\x18\x01 \x01(\t\"\x15\n\x13UpdateTokenResponse\"*\n\x0cMetadataItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\"\x87\x12\n\x12StreamWriteMessage\x1a\xe5\x01\n\nFromClient\x12\x41\n\x0cinit_request\x18\x01 \x01(\x0b\x32).Ydb.Topic.StreamWriteMessage.InitRequestH\x00\x12\x43\n\rwrite_request\x18\x02 \x01(\x0b\x32*.Ydb.Topic.StreamWriteMessage.WriteRequestH\x00\x12=\n\x14update_token_request\x18\x03 \x01(\x0b\x32\x1d.Ydb.Topic.UpdateTokenRequestH\x00\x42\x10\n\x0e\x63lient_message\x1a\xbf\x02\n\nFromServer\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x43\n\rinit_response\x18\x03 \x01(\x0b\x32*.Ydb.Topic.StreamWriteMessage.InitResponseH\x00\x12\x45\n\x0ewrite_response\x18\x04 \x01(\x0b\x32+.Ydb.Topic.StreamWriteMessage.WriteResponseH\x00\x12?\n\x15update_token_response\x18\x05 \x01(\x0b\x32\x1e.Ydb.Topic.UpdateTokenResponseH\x00\x42\x10\n\x0eserver_message\x1a\xa3\x02\n\x0bInitRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x13\n\x0bproducer_id\x18\x02 \x01(\t\x12[\n\x12write_session_meta\x18\x03 \x03(\x0b\x32?.Ydb.Topic.StreamWriteMessage.InitRequest.WriteSessionMetaEntry\x12\x1a\n\x10message_group_id\x18\x04 \x01(\tH\x00\x12\x16\n\x0cpartition_id\x18\x05 \x01(\x03H\x00\x12\x17\n\x0fget_last_seq_no\x18\x06 \x01(\x08\x1a\x37\n\x15WriteSessionMetaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0e\n\x0cpartitioning\x1a\x83\x01\n\x0cInitResponse\x12\x13\n\x0blast_seq_no\x18\x01 \x01(\x03\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x03\x12\x34\n\x10supported_codecs\x18\x04 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x1a\x96\x03\n\x0cWriteRequest\x12H\n\x08messages\x18\x01 \x03(\x0b\x32\x36.Ydb.Topic.StreamWriteMessage.WriteRequest.MessageData\x12\r\n\x05\x63odec\x18\x02 \x01(\x05\x12/\n\x02tx\x18\x03 \x01(\x0b\x32\x1e.Ydb.Topic.TransactionIdentityH\x00\x88\x01\x01\x1a\xf4\x01\n\x0bMessageData\x12\x0e\n\x06seq_no\x18\x01 \x01(\x03\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12\x19\n\x11uncompressed_size\x18\x04 \x01(\x03\x12\x1a\n\x10message_group_id\x18\x05 \x01(\tH\x00\x12\x16\n\x0cpartition_id\x18\x06 \x01(\x03H\x00\x12\x38\n\x0emetadata_items\x18\x07 \x03(\x0b\x32\x17.Ydb.Topic.MetadataItemB\x07\x9a\xe6*\x03\x18\xe8\x07\x42\x0e\n\x0cpartitioningB\x05\n\x03_tx\x1a\x81\x07\n\rWriteResponse\x12\x42\n\x04\x61\x63ks\x18\x01 \x03(\x0b\x32\x34.Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck\x12\x14\n\x0cpartition_id\x18\x02 \x01(\x03\x12U\n\x10write_statistics\x18\x03 \x01(\x0b\x32;.Ydb.Topic.StreamWriteMessage.WriteResponse.WriteStatistics\x1a\x8e\x03\n\x08WriteAck\x12\x0e\n\x06seq_no\x18\x01 \x01(\x03\x12O\n\x07written\x18\x02 \x01(\x0b\x32<.Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.WrittenH\x00\x12O\n\x07skipped\x18\x03 \x01(\x0b\x32<.Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.SkippedH\x00\x1a\x19\n\x07Written\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x1a\x9c\x01\n\x07Skipped\x12S\n\x06reason\x18\x01 \x01(\x0e\x32\x43.Ydb.Topic.StreamWriteMessage.WriteResponse.WriteAck.Skipped.Reason\"<\n\x06Reason\x12\x16\n\x12REASON_UNSPECIFIED\x10\x00\x12\x1a\n\x16REASON_ALREADY_WRITTEN\x10\x01\x42\x16\n\x14message_write_status\x1a\xad\x02\n\x0fWriteStatistics\x12\x32\n\x0fpersisting_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x36\n\x13min_queue_wait_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x36\n\x13max_queue_wait_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12<\n\x19partition_quota_wait_time\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x38\n\x15topic_quota_wait_time\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xca\x1d\n\x11StreamReadMessage\x1aT\n\x10PartitionSession\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x03\x1a\xea\x04\n\nFromClient\x12@\n\x0cinit_request\x18\x01 \x01(\x0b\x32(.Ydb.Topic.StreamReadMessage.InitRequestH\x00\x12@\n\x0cread_request\x18\x02 \x01(\x0b\x32(.Ydb.Topic.StreamReadMessage.ReadRequestH\x00\x12Q\n\x15\x63ommit_offset_request\x18\x03 \x01(\x0b\x32\x30.Ydb.Topic.StreamReadMessage.CommitOffsetRequestH\x00\x12\x66\n partition_session_status_request\x18\x04 \x01(\x0b\x32:.Ydb.Topic.StreamReadMessage.PartitionSessionStatusRequestH\x00\x12=\n\x14update_token_request\x18\x05 \x01(\x0b\x32\x1d.Ydb.Topic.UpdateTokenRequestH\x00\x12\x66\n start_partition_session_response\x18\x06 \x01(\x0b\x32:.Ydb.Topic.StreamReadMessage.StartPartitionSessionResponseH\x00\x12\x64\n\x1fstop_partition_session_response\x18\x07 \x01(\x0b\x32\x39.Ydb.Topic.StreamReadMessage.StopPartitionSessionResponseH\x00\x42\x10\n\x0e\x63lient_message\x1a\xc4\x05\n\nFromServer\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x42\n\rinit_response\x18\x03 \x01(\x0b\x32).Ydb.Topic.StreamReadMessage.InitResponseH\x00\x12\x42\n\rread_response\x18\x04 \x01(\x0b\x32).Ydb.Topic.StreamReadMessage.ReadResponseH\x00\x12S\n\x16\x63ommit_offset_response\x18\x05 \x01(\x0b\x32\x31.Ydb.Topic.StreamReadMessage.CommitOffsetResponseH\x00\x12h\n!partition_session_status_response\x18\x06 \x01(\x0b\x32;.Ydb.Topic.StreamReadMessage.PartitionSessionStatusResponseH\x00\x12?\n\x15update_token_response\x18\x07 \x01(\x0b\x32\x1e.Ydb.Topic.UpdateTokenResponseH\x00\x12\x64\n\x1fstart_partition_session_request\x18\x08 \x01(\x0b\x32\x39.Ydb.Topic.StreamReadMessage.StartPartitionSessionRequestH\x00\x12\x62\n\x1estop_partition_session_request\x18\t \x01(\x0b\x32\x38.Ydb.Topic.StreamReadMessage.StopPartitionSessionRequestH\x00\x42\x10\n\x0eserver_message\x1a\xa4\x02\n\x0bInitRequest\x12X\n\x14topics_read_settings\x18\x01 \x03(\x0b\x32:.Ydb.Topic.StreamReadMessage.InitRequest.TopicReadSettings\x12\x10\n\x08\x63onsumer\x18\x02 \x01(\t\x12\x13\n\x0breader_name\x18\x03 \x01(\t\x1a\x93\x01\n\x11TopicReadSettings\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x15\n\rpartition_ids\x18\x02 \x03(\x03\x12*\n\x07max_lag\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12-\n\tread_from\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\"\n\x0cInitResponse\x12\x12\n\nsession_id\x18\x01 \x01(\t\x1a!\n\x0bReadRequest\x12\x12\n\nbytes_size\x18\x01 \x01(\x03\x1a\xff\x05\n\x0cReadResponse\x12O\n\x0epartition_data\x18\x01 \x03(\x0b\x32\x37.Ydb.Topic.StreamReadMessage.ReadResponse.PartitionData\x12\x12\n\nbytes_size\x18\x02 \x01(\x03\x1a\xd1\x01\n\x0bMessageData\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x0e\n\x06seq_no\x18\x02 \x01(\x03\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\x12\x19\n\x11uncompressed_size\x18\x06 \x01(\x03\x12\x18\n\x10message_group_id\x18\x07 \x01(\t\x12/\n\x0emetadata_items\x18\x08 \x03(\x0b\x32\x17.Ydb.Topic.MetadataItem\x1a\xc4\x02\n\x05\x42\x61tch\x12K\n\x0cmessage_data\x18\x01 \x03(\x0b\x32\x35.Ydb.Topic.StreamReadMessage.ReadResponse.MessageData\x12\x13\n\x0bproducer_id\x18\x02 \x01(\t\x12\x61\n\x12write_session_meta\x18\x03 \x03(\x0b\x32\x45.Ydb.Topic.StreamReadMessage.ReadResponse.Batch.WriteSessionMetaEntry\x12\r\n\x05\x63odec\x18\x04 \x01(\x05\x12.\n\nwritten_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x37\n\x15WriteSessionMetaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1ao\n\rPartitionData\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12@\n\x07\x62\x61tches\x18\x02 \x03(\x0b\x32/.Ydb.Topic.StreamReadMessage.ReadResponse.Batch\x1a\xd6\x01\n\x13\x43ommitOffsetRequest\x12^\n\x0e\x63ommit_offsets\x18\x01 \x03(\x0b\x32\x46.Ydb.Topic.StreamReadMessage.CommitOffsetRequest.PartitionCommitOffset\x1a_\n\x15PartitionCommitOffset\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12(\n\x07offsets\x18\x02 \x03(\x0b\x32\x17.Ydb.Topic.OffsetsRange\x1a\xdc\x01\n\x14\x43ommitOffsetResponse\x12p\n\x1cpartitions_committed_offsets\x18\x01 \x03(\x0b\x32J.Ydb.Topic.StreamReadMessage.CommitOffsetResponse.PartitionCommittedOffset\x1aR\n\x18PartitionCommittedOffset\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x18\n\x10\x63ommitted_offset\x18\x02 \x01(\x03\x1a=\n\x1dPartitionSessionStatusRequest\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x1a\xcb\x01\n\x1ePartitionSessionStatusResponse\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x32\n\x11partition_offsets\x18\x02 \x01(\x0b\x32\x17.Ydb.Topic.OffsetsRange\x12\x18\n\x10\x63ommitted_offset\x18\x03 \x01(\x03\x12=\n\x19write_time_high_watermark\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\xb6\x01\n\x1cStartPartitionSessionRequest\x12H\n\x11partition_session\x18\x01 \x01(\x0b\x32-.Ydb.Topic.StreamReadMessage.PartitionSession\x12\x18\n\x10\x63ommitted_offset\x18\x02 \x01(\x03\x12\x32\n\x11partition_offsets\x18\x03 \x01(\x0b\x32\x17.Ydb.Topic.OffsetsRange\x1a\x95\x01\n\x1dStartPartitionSessionResponse\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x18\n\x0bread_offset\x18\x02 \x01(\x03H\x00\x88\x01\x01\x12\x1a\n\rcommit_offset\x18\x03 \x01(\x03H\x01\x88\x01\x01\x42\x0e\n\x0c_read_offsetB\x10\n\x0e_commit_offset\x1ag\n\x1bStopPartitionSessionRequest\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x10\n\x08graceful\x18\x02 \x01(\x08\x12\x18\n\x10\x63ommitted_offset\x18\x03 \x01(\x03\x1a<\n\x1cStopPartitionSessionResponse\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\"2\n\x13TransactionIdentity\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07session\x18\x02 \x01(\t\"\xc4\x03\n!UpdateOffsetsInTransactionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12*\n\x02tx\x18\x02 \x01(\x0b\x32\x1e.Ydb.Topic.TransactionIdentity\x12I\n\x06topics\x18\x03 \x03(\x0b\x32\x39.Ydb.Topic.UpdateOffsetsInTransactionRequest.TopicOffsets\x12\x10\n\x08\x63onsumer\x18\x04 \x01(\t\x1a\xda\x01\n\x0cTopicOffsets\x12\x0c\n\x04path\x18\x01 \x01(\t\x12^\n\npartitions\x18\x02 \x03(\x0b\x32J.Ydb.Topic.UpdateOffsetsInTransactionRequest.TopicOffsets.PartitionOffsets\x1a\\\n\x10PartitionOffsets\x12\x14\n\x0cpartition_id\x18\x01 \x01(\x03\x12\x32\n\x11partition_offsets\x18\x02 \x03(\x0b\x32\x17.Ydb.Topic.OffsetsRange\"R\n\"UpdateOffsetsInTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\"\n UpdateOffsetsInTransactionResult\"\x96\x01\n\x13\x43ommitOffsetRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x03\x12\x10\n\x08\x63onsumer\x18\x04 \x01(\t\x12\x0e\n\x06offset\x18\x05 \x01(\x03\"D\n\x14\x43ommitOffsetResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x14\n\x12\x43ommitOffsetResult\"L\n\x13MultipleWindowsStat\x12\x12\n\nper_minute\x18\x01 \x01(\x03\x12\x10\n\x08per_hour\x18\x02 \x01(\x03\x12\x0f\n\x07per_day\x18\x03 \x01(\x03\"\xb3\x04\n\x08\x43onsumer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\timportant\x18\x02 \x01(\x08\x12-\n\tread_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10supported_codecs\x18\x05 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x12\x37\n\nattributes\x18\x06 \x03(\x0b\x32#.Ydb.Topic.Consumer.AttributesEntry\x12\x39\n\x0e\x63onsumer_stats\x18\x07 \x01(\x0b\x32!.Ydb.Topic.Consumer.ConsumerStats\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xf3\x01\n\rConsumerStats\x12\x41\n\x1dmin_partitions_last_read_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x11max_read_time_lag\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\x12max_write_time_lag\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x32\n\nbytes_read\x18\x04 \x01(\x0b\x32\x1e.Ydb.Topic.MultipleWindowsStatJ\x04\x08\x04\x10\x05\"\xbf\x02\n\rAlterConsumer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1a\n\rset_important\x18\x02 \x01(\x08H\x00\x88\x01\x01\x12\x31\n\rset_read_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14set_supported_codecs\x18\x05 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x12G\n\x10\x61lter_attributes\x18\x06 \x03(\x0b\x32-.Ydb.Topic.AlterConsumer.AlterAttributesEntry\x1a\x36\n\x14\x41lterAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x10\n\x0e_set_importantJ\x04\x08\x04\x10\x05\"h\n\x14PartitioningSettings\x12\'\n\x15min_active_partitions\x18\x01 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\'\n\x15partition_count_limit\x18\x02 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\"\xbb\x01\n\x19\x41lterPartitioningSettings\x12\x30\n\x19set_min_active_partitions\x18\x01 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0H\x00\x88\x01\x01\x12\x30\n\x19set_partition_count_limit\x18\x02 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0H\x01\x88\x01\x01\x42\x1c\n\x1a_set_min_active_partitionsB\x1c\n\x1a_set_partition_count_limit\"\xf6\x04\n\x12\x43reateTopicRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12>\n\x15partitioning_settings\x18\x03 \x01(\x0b\x32\x1f.Ydb.Topic.PartitioningSettings\x12\x33\n\x10retention_period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12&\n\x14retention_storage_mb\x18\x05 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x34\n\x10supported_codecs\x18\x07 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x12\x38\n&partition_write_speed_bytes_per_second\x18\x08 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12-\n\x1bpartition_write_burst_bytes\x18\t \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x41\n\nattributes\x18\n \x03(\x0b\x32-.Ydb.Topic.CreateTopicRequest.AttributesEntry\x12/\n\tconsumers\x18\x0b \x03(\x0b\x32\x13.Ydb.Topic.ConsumerB\x07\x9a\xe6*\x03\x18\xb8\x17\x12.\n\rmetering_mode\x18\x0c \x01(\x0e\x32\x17.Ydb.Topic.MeteringMode\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x06\x10\x07\"C\n\x13\x43reateTopicResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x13\n\x11\x43reateTopicResult\"v\n\x14\x44\x65scribeTopicRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x15\n\rinclude_stats\x18\x03 \x01(\x08\"E\n\x15\x44\x65scribeTopicResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xa2\x08\n\x13\x44\x65scribeTopicResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12>\n\x15partitioning_settings\x18\x02 \x01(\x0b\x32\x1f.Ydb.Topic.PartitioningSettings\x12@\n\npartitions\x18\x03 \x03(\x0b\x32,.Ydb.Topic.DescribeTopicResult.PartitionInfo\x12\x33\n\x10retention_period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1c\n\x14retention_storage_mb\x18\x05 \x01(\x03\x12\x34\n\x10supported_codecs\x18\x07 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x12.\n&partition_write_speed_bytes_per_second\x18\x08 \x01(\x03\x12#\n\x1bpartition_write_burst_bytes\x18\t \x01(\x03\x12\x42\n\nattributes\x18\n \x03(\x0b\x32..Ydb.Topic.DescribeTopicResult.AttributesEntry\x12&\n\tconsumers\x18\x0b \x03(\x0b\x32\x13.Ydb.Topic.Consumer\x12.\n\rmetering_mode\x18\x0c \x01(\x0e\x32\x17.Ydb.Topic.MeteringMode\x12>\n\x0btopic_stats\x18\r \x01(\x0b\x32).Ydb.Topic.DescribeTopicResult.TopicStats\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xa4\x01\n\rPartitionInfo\x12\x14\n\x0cpartition_id\x18\x01 \x01(\x03\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\x1b\n\x13\x63hild_partition_ids\x18\x03 \x03(\x03\x12\x1c\n\x14parent_partition_ids\x18\x04 \x03(\x03\x12\x32\n\x0fpartition_stats\x18\x05 \x01(\x0b\x32\x19.Ydb.Topic.PartitionStats\x1a\xcd\x01\n\nTopicStats\x12\x18\n\x10store_size_bytes\x18\x01 \x01(\x03\x12\x37\n\x13min_last_write_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x12max_write_time_lag\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\rbytes_written\x18\x04 \x01(\x0b\x32\x1e.Ydb.Topic.MultipleWindowsStatJ\x04\x08\x06\x10\x07\"\x8b\x01\n\x17\x44\x65scribeConsumerRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x10\n\x08\x63onsumer\x18\x03 \x01(\t\x12\x15\n\rinclude_stats\x18\x04 \x01(\x08\"H\n\x18\x44\x65scribeConsumerResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xde\x06\n\x16\x44\x65scribeConsumerResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12%\n\x08\x63onsumer\x18\x02 \x01(\x0b\x32\x13.Ydb.Topic.Consumer\x12\x43\n\npartitions\x18\x03 \x03(\x0b\x32/.Ydb.Topic.DescribeConsumerResult.PartitionInfo\x1a\x80\x02\n\rPartitionInfo\x12\x14\n\x0cpartition_id\x18\x01 \x01(\x03\x12\x0e\n\x06\x61\x63tive\x18\x02 \x01(\x08\x12\x1b\n\x13\x63hild_partition_ids\x18\x03 \x03(\x03\x12\x1c\n\x14parent_partition_ids\x18\x04 \x03(\x03\x12\x32\n\x0fpartition_stats\x18\x05 \x01(\x0b\x32\x19.Ydb.Topic.PartitionStats\x12Z\n\x18partition_consumer_stats\x18\x06 \x01(\x0b\x32\x38.Ydb.Topic.DescribeConsumerResult.PartitionConsumerStats\x1a\xb3\x03\n\x16PartitionConsumerStats\x12\x18\n\x10last_read_offset\x18\x01 \x01(\x03\x12\x18\n\x10\x63ommitted_offset\x18\x02 \x01(\x03\x12\x17\n\x0fread_session_id\x18\x03 \x01(\t\x12\x46\n\"partition_read_session_create_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0elast_read_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x11max_read_time_lag\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\x12max_write_time_lag\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x32\n\nbytes_read\x18\x08 \x01(\x0b\x32\x1e.Ydb.Topic.MultipleWindowsStat\x12\x13\n\x0breader_name\x18\x0b \x01(\t\x12\x1a\n\x12\x63onnection_node_id\x18\x0c \x01(\x05\"\x9c\x02\n\x0ePartitionStats\x12\x32\n\x11partition_offsets\x18\x01 \x01(\x0b\x32\x17.Ydb.Topic.OffsetsRange\x12\x18\n\x10store_size_bytes\x18\x02 \x01(\x03\x12\x33\n\x0flast_write_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x12max_write_time_lag\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x35\n\rbytes_written\x18\x05 \x01(\x0b\x32\x1e.Ydb.Topic.MultipleWindowsStat\x12\x19\n\x11partition_node_id\x18\x08 \x01(\x05\"\x87\x07\n\x11\x41lterTopicRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12I\n\x1b\x61lter_partitioning_settings\x18\x03 \x01(\x0b\x32$.Ydb.Topic.AlterPartitioningSettings\x12\x37\n\x14set_retention_period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x18set_retention_storage_mb\x18\x05 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0H\x00\x88\x01\x01\x12\x38\n\x14set_supported_codecs\x18\x07 \x01(\x0b\x32\x1a.Ydb.Topic.SupportedCodecs\x12\x41\n*set_partition_write_speed_bytes_per_second\x18\x08 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0H\x01\x88\x01\x01\x12\x36\n\x1fset_partition_write_burst_bytes\x18\t \x01(\x03\x42\x08\xb2\xe6*\x04>= 0H\x02\x88\x01\x01\x12K\n\x10\x61lter_attributes\x18\n \x03(\x0b\x32\x31.Ydb.Topic.AlterTopicRequest.AlterAttributesEntry\x12\x33\n\radd_consumers\x18\x0b \x03(\x0b\x32\x13.Ydb.Topic.ConsumerB\x07\x9a\xe6*\x03\x18\xb8\x17\x12\x1f\n\x0e\x64rop_consumers\x18\x0c \x03(\tB\x07\x9a\xe6*\x03\x18\xb8\x17\x12:\n\x0f\x61lter_consumers\x18\r \x03(\x0b\x32\x18.Ydb.Topic.AlterConsumerB\x07\x9a\xe6*\x03\x18\xb8\x17\x12\x32\n\x11set_metering_mode\x18\x0e \x01(\x0e\x32\x17.Ydb.Topic.MeteringMode\x1a\x36\n\x14\x41lterAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x1b\n\x19_set_retention_storage_mbB-\n+_set_partition_write_speed_bytes_per_secondB\"\n _set_partition_write_burst_bytesJ\x04\x08\x06\x10\x07\"B\n\x12\x41lterTopicResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x12\n\x10\x41lterTopicResult\"[\n\x10\x44ropTopicRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"A\n\x11\x44ropTopicResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x11\n\x0f\x44ropTopicResult*\x83\x01\n\x05\x43odec\x12\x15\n\x11\x43ODEC_UNSPECIFIED\x10\x00\x12\r\n\tCODEC_RAW\x10\x01\x12\x0e\n\nCODEC_GZIP\x10\x02\x12\x0e\n\nCODEC_LZOP\x10\x03\x12\x0e\n\nCODEC_ZSTD\x10\x04\x12\x11\n\x0c\x43ODEC_CUSTOM\x10\x90N\"\x05\x08\x05\x10\x8fN\"\n\x08\xa0\x9c\x01\x10\xff\xff\xff\xff\x07*s\n\x0cMeteringMode\x12\x1d\n\x19METERING_MODE_UNSPECIFIED\x10\x00\x12#\n\x1fMETERING_MODE_RESERVED_CAPACITY\x10\x01\x12\x1f\n\x1bMETERING_MODE_REQUEST_UNITS\x10\x02\x42S\n\x14tech.ydb.proto.topicZ8github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Topic\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_topic_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024tech.ydb.proto.topicZ8github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Topic\370\001\001'
  _SUPPORTEDCODECS.fields_by_name['codecs']._options = None
  _SUPPORTEDCODECS.fields_by_name['codecs']._serialized_options = b'\262\346*\n[1; 19999]\232\346*\002\030d'
  _STREAMWRITEMESSAGE_INITREQUEST_WRITESESSIONMETAENTRY._options = None
  _STREAMWRITEMESSAGE_INITREQUEST_WRITESESSIONMETAENTRY._serialized_options = b'8\001'
  _STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA.fields_by_name['metadata_items']._options = None
  _STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA.fields_by_name['metadata_items']._serialized_options = b'\232\346*\003\030\350\007'
  _STREAMREADMESSAGE_READRESPONSE_BATCH_WRITESESSIONMETAENTRY._options = None
  _STREAMREADMESSAGE_READRESPONSE_BATCH_WRITESESSIONMETAENTRY._serialized_options = b'8\001'
  _CONSUMER_ATTRIBUTESENTRY._options = None
  _CONSUMER_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _ALTERCONSUMER_ALTERATTRIBUTESENTRY._options = None
  _ALTERCONSUMER_ALTERATTRIBUTESENTRY._serialized_options = b'8\001'
  _PARTITIONINGSETTINGS.fields_by_name['min_active_partitions']._options = None
  _PARTITIONINGSETTINGS.fields_by_name['min_active_partitions']._serialized_options = b'\262\346*\004>= 0'
  _PARTITIONINGSETTINGS.fields_by_name['partition_count_limit']._options = None
  _PARTITIONINGSETTINGS.fields_by_name['partition_count_limit']._serialized_options = b'\262\346*\004>= 0'
  _ALTERPARTITIONINGSETTINGS.fields_by_name['set_min_active_partitions']._options = None
  _ALTERPARTITIONINGSETTINGS.fields_by_name['set_min_active_partitions']._serialized_options = b'\262\346*\004>= 0'
  _ALTERPARTITIONINGSETTINGS.fields_by_name['set_partition_count_limit']._options = None
  _ALTERPARTITIONINGSETTINGS.fields_by_name['set_partition_count_limit']._serialized_options = b'\262\346*\004>= 0'
  _CREATETOPICREQUEST_ATTRIBUTESENTRY._options = None
  _CREATETOPICREQUEST_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _CREATETOPICREQUEST.fields_by_name['retention_storage_mb']._options = None
  _CREATETOPICREQUEST.fields_by_name['retention_storage_mb']._serialized_options = b'\262\346*\004>= 0'
  _CREATETOPICREQUEST.fields_by_name['partition_write_speed_bytes_per_second']._options = None
  _CREATETOPICREQUEST.fields_by_name['partition_write_speed_bytes_per_second']._serialized_options = b'\262\346*\004>= 0'
  _CREATETOPICREQUEST.fields_by_name['partition_write_burst_bytes']._options = None
  _CREATETOPICREQUEST.fields_by_name['partition_write_burst_bytes']._serialized_options = b'\262\346*\004>= 0'
  _CREATETOPICREQUEST.fields_by_name['consumers']._options = None
  _CREATETOPICREQUEST.fields_by_name['consumers']._serialized_options = b'\232\346*\003\030\270\027'
  _DESCRIBETOPICRESULT_ATTRIBUTESENTRY._options = None
  _DESCRIBETOPICRESULT_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _ALTERTOPICREQUEST_ALTERATTRIBUTESENTRY._options = None
  _ALTERTOPICREQUEST_ALTERATTRIBUTESENTRY._serialized_options = b'8\001'
  _ALTERTOPICREQUEST.fields_by_name['set_retention_storage_mb']._options = None
  _ALTERTOPICREQUEST.fields_by_name['set_retention_storage_mb']._serialized_options = b'\262\346*\004>= 0'
  _ALTERTOPICREQUEST.fields_by_name['set_partition_write_speed_bytes_per_second']._options = None
  _ALTERTOPICREQUEST.fields_by_name['set_partition_write_speed_bytes_per_second']._serialized_options = b'\262\346*\004>= 0'
  _ALTERTOPICREQUEST.fields_by_name['set_partition_write_burst_bytes']._options = None
  _ALTERTOPICREQUEST.fields_by_name['set_partition_write_burst_bytes']._serialized_options = b'\262\346*\004>= 0'
  _ALTERTOPICREQUEST.fields_by_name['add_consumers']._options = None
  _ALTERTOPICREQUEST.fields_by_name['add_consumers']._serialized_options = b'\232\346*\003\030\270\027'
  _ALTERTOPICREQUEST.fields_by_name['drop_consumers']._options = None
  _ALTERTOPICREQUEST.fields_by_name['drop_consumers']._serialized_options = b'\232\346*\003\030\270\027'
  _ALTERTOPICREQUEST.fields_by_name['alter_consumers']._options = None
  _ALTERTOPICREQUEST.fields_by_name['alter_consumers']._serialized_options = b'\232\346*\003\030\270\027'
  _CODEC._serialized_start=13214
  _CODEC._serialized_end=13345
  _METERINGMODE._serialized_start=13347
  _METERINGMODE._serialized_end=13462
  _SUPPORTEDCODECS._serialized_start=255
  _SUPPORTEDCODECS._serialized_end=310
  _OFFSETSRANGE._serialized_start=312
  _OFFSETSRANGE._serialized_end=354
  _UPDATETOKENREQUEST._serialized_start=356
  _UPDATETOKENREQUEST._serialized_end=391
  _UPDATETOKENRESPONSE._serialized_start=393
  _UPDATETOKENRESPONSE._serialized_end=414
  _METADATAITEM._serialized_start=416
  _METADATAITEM._serialized_end=458
  _STREAMWRITEMESSAGE._serialized_start=461
  _STREAMWRITEMESSAGE._serialized_end=2772
  _STREAMWRITEMESSAGE_FROMCLIENT._serialized_start=484
  _STREAMWRITEMESSAGE_FROMCLIENT._serialized_end=713
  _STREAMWRITEMESSAGE_FROMSERVER._serialized_start=716
  _STREAMWRITEMESSAGE_FROMSERVER._serialized_end=1035
  _STREAMWRITEMESSAGE_INITREQUEST._serialized_start=1038
  _STREAMWRITEMESSAGE_INITREQUEST._serialized_end=1329
  _STREAMWRITEMESSAGE_INITREQUEST_WRITESESSIONMETAENTRY._serialized_start=1258
  _STREAMWRITEMESSAGE_INITREQUEST_WRITESESSIONMETAENTRY._serialized_end=1313
  _STREAMWRITEMESSAGE_INITRESPONSE._serialized_start=1332
  _STREAMWRITEMESSAGE_INITRESPONSE._serialized_end=1463
  _STREAMWRITEMESSAGE_WRITEREQUEST._serialized_start=1466
  _STREAMWRITEMESSAGE_WRITEREQUEST._serialized_end=1872
  _STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA._serialized_start=1621
  _STREAMWRITEMESSAGE_WRITEREQUEST_MESSAGEDATA._serialized_end=1865
  _STREAMWRITEMESSAGE_WRITERESPONSE._serialized_start=1875
  _STREAMWRITEMESSAGE_WRITERESPONSE._serialized_end=2772
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK._serialized_start=2070
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK._serialized_end=2468
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_WRITTEN._serialized_start=2260
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_WRITTEN._serialized_end=2285
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED._serialized_start=2288
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED._serialized_end=2444
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED_REASON._serialized_start=2384
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITEACK_SKIPPED_REASON._serialized_end=2444
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITESTATISTICS._serialized_start=2471
  _STREAMWRITEMESSAGE_WRITERESPONSE_WRITESTATISTICS._serialized_end=2772
  _STREAMREADMESSAGE._serialized_start=2775
  _STREAMREADMESSAGE._serialized_end=6561
  _STREAMREADMESSAGE_PARTITIONSESSION._serialized_start=2796
  _STREAMREADMESSAGE_PARTITIONSESSION._serialized_end=2880
  _STREAMREADMESSAGE_FROMCLIENT._serialized_start=2883
  _STREAMREADMESSAGE_FROMCLIENT._serialized_end=3501
  _STREAMREADMESSAGE_FROMSERVER._serialized_start=3504
  _STREAMREADMESSAGE_FROMSERVER._serialized_end=4212
  _STREAMREADMESSAGE_INITREQUEST._serialized_start=4215
  _STREAMREADMESSAGE_INITREQUEST._serialized_end=4507
  _STREAMREADMESSAGE_INITREQUEST_TOPICREADSETTINGS._serialized_start=4360
  _STREAMREADMESSAGE_INITREQUEST_TOPICREADSETTINGS._serialized_end=4507
  _STREAMREADMESSAGE_INITRESPONSE._serialized_start=4509
  _STREAMREADMESSAGE_INITRESPONSE._serialized_end=4543
  _STREAMREADMESSAGE_READREQUEST._serialized_start=4545
  _STREAMREADMESSAGE_READREQUEST._serialized_end=4578
  _STREAMREADMESSAGE_READRESPONSE._serialized_start=4581
  _STREAMREADMESSAGE_READRESPONSE._serialized_end=5348
  _STREAMREADMESSAGE_READRESPONSE_MESSAGEDATA._serialized_start=4699
  _STREAMREADMESSAGE_READRESPONSE_MESSAGEDATA._serialized_end=4908
  _STREAMREADMESSAGE_READRESPONSE_BATCH._serialized_start=4911
  _STREAMREADMESSAGE_READRESPONSE_BATCH._serialized_end=5235
  _STREAMREADMESSAGE_READRESPONSE_BATCH_WRITESESSIONMETAENTRY._serialized_start=1258
  _STREAMREADMESSAGE_READRESPONSE_BATCH_WRITESESSIONMETAENTRY._serialized_end=1313
  _STREAMREADMESSAGE_READRESPONSE_PARTITIONDATA._serialized_start=5237
  _STREAMREADMESSAGE_READRESPONSE_PARTITIONDATA._serialized_end=5348
  _STREAMREADMESSAGE_COMMITOFFSETREQUEST._serialized_start=5351
  _STREAMREADMESSAGE_COMMITOFFSETREQUEST._serialized_end=5565
  _STREAMREADMESSAGE_COMMITOFFSETREQUEST_PARTITIONCOMMITOFFSET._serialized_start=5470
  _STREAMREADMESSAGE_COMMITOFFSETREQUEST_PARTITIONCOMMITOFFSET._serialized_end=5565
  _STREAMREADMESSAGE_COMMITOFFSETRESPONSE._serialized_start=5568
  _STREAMREADMESSAGE_COMMITOFFSETRESPONSE._serialized_end=5788
  _STREAMREADMESSAGE_COMMITOFFSETRESPONSE_PARTITIONCOMMITTEDOFFSET._serialized_start=5706
  _STREAMREADMESSAGE_COMMITOFFSETRESPONSE_PARTITIONCOMMITTEDOFFSET._serialized_end=5788
  _STREAMREADMESSAGE_PARTITIONSESSIONSTATUSREQUEST._serialized_start=5790
  _STREAMREADMESSAGE_PARTITIONSESSIONSTATUSREQUEST._serialized_end=5851
  _STREAMREADMESSAGE_PARTITIONSESSIONSTATUSRESPONSE._serialized_start=5854
  _STREAMREADMESSAGE_PARTITIONSESSIONSTATUSRESPONSE._serialized_end=6057
  _STREAMREADMESSAGE_STARTPARTITIONSESSIONREQUEST._serialized_start=6060
  _STREAMREADMESSAGE_STARTPARTITIONSESSIONREQUEST._serialized_end=6242
  _STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE._serialized_start=6245
  _STREAMREADMESSAGE_STARTPARTITIONSESSIONRESPONSE._serialized_end=6394
  _STREAMREADMESSAGE_STOPPARTITIONSESSIONREQUEST._serialized_start=6396
  _STREAMREADMESSAGE_STOPPARTITIONSESSIONREQUEST._serialized_end=6499
  _STREAMREADMESSAGE_STOPPARTITIONSESSIONRESPONSE._serialized_start=6501
  _STREAMREADMESSAGE_STOPPARTITIONSESSIONRESPONSE._serialized_end=6561
  _TRANSACTIONIDENTITY._serialized_start=6563
  _TRANSACTIONIDENTITY._serialized_end=6613
  _UPDATEOFFSETSINTRANSACTIONREQUEST._serialized_start=6616
  _UPDATEOFFSETSINTRANSACTIONREQUEST._serialized_end=7068
  _UPDATEOFFSETSINTRANSACTIONREQUEST_TOPICOFFSETS._serialized_start=6850
  _UPDATEOFFSETSINTRANSACTIONREQUEST_TOPICOFFSETS._serialized_end=7068
  _UPDATEOFFSETSINTRANSACTIONREQUEST_TOPICOFFSETS_PARTITIONOFFSETS._serialized_start=6976
  _UPDATEOFFSETSINTRANSACTIONREQUEST_TOPICOFFSETS_PARTITIONOFFSETS._serialized_end=7068
  _UPDATEOFFSETSINTRANSACTIONRESPONSE._serialized_start=7070
  _UPDATEOFFSETSINTRANSACTIONRESPONSE._serialized_end=7152
  _UPDATEOFFSETSINTRANSACTIONRESULT._serialized_start=7154
  _UPDATEOFFSETSINTRANSACTIONRESULT._serialized_end=7188
  _COMMITOFFSETREQUEST._serialized_start=7191
  _COMMITOFFSETREQUEST._serialized_end=7341
  _COMMITOFFSETRESPONSE._serialized_start=7343
  _COMMITOFFSETRESPONSE._serialized_end=7411
  _COMMITOFFSETRESULT._serialized_start=7413
  _COMMITOFFSETRESULT._serialized_end=7433
  _MULTIPLEWINDOWSSTAT._serialized_start=7435
  _MULTIPLEWINDOWSSTAT._serialized_end=7511
  _CONSUMER._serialized_start=7514
  _CONSUMER._serialized_end=8077
  _CONSUMER_ATTRIBUTESENTRY._serialized_start=7776
  _CONSUMER_ATTRIBUTESENTRY._serialized_end=7825
  _CONSUMER_CONSUMERSTATS._serialized_start=7828
  _CONSUMER_CONSUMERSTATS._serialized_end=8071
  _ALTERCONSUMER._serialized_start=8080
  _ALTERCONSUMER._serialized_end=8399
  _ALTERCONSUMER_ALTERATTRIBUTESENTRY._serialized_start=8321
  _ALTERCONSUMER_ALTERATTRIBUTESENTRY._serialized_end=8375
  _PARTITIONINGSETTINGS._serialized_start=8401
  _PARTITIONINGSETTINGS._serialized_end=8505
  _ALTERPARTITIONINGSETTINGS._serialized_start=8508
  _ALTERPARTITIONINGSETTINGS._serialized_end=8695
  _CREATETOPICREQUEST._serialized_start=8698
  _CREATETOPICREQUEST._serialized_end=9328
  _CREATETOPICREQUEST_ATTRIBUTESENTRY._serialized_start=7776
  _CREATETOPICREQUEST_ATTRIBUTESENTRY._serialized_end=7825
  _CREATETOPICRESPONSE._serialized_start=9330
  _CREATETOPICRESPONSE._serialized_end=9397
  _CREATETOPICRESULT._serialized_start=9399
  _CREATETOPICRESULT._serialized_end=9418
  _DESCRIBETOPICREQUEST._serialized_start=9420
  _DESCRIBETOPICREQUEST._serialized_end=9538
  _DESCRIBETOPICRESPONSE._serialized_start=9540
  _DESCRIBETOPICRESPONSE._serialized_end=9609
  _DESCRIBETOPICRESULT._serialized_start=9612
  _DESCRIBETOPICRESULT._serialized_end=10670
  _DESCRIBETOPICRESULT_ATTRIBUTESENTRY._serialized_start=7776
  _DESCRIBETOPICRESULT_ATTRIBUTESENTRY._serialized_end=7825
  _DESCRIBETOPICRESULT_PARTITIONINFO._serialized_start=10292
  _DESCRIBETOPICRESULT_PARTITIONINFO._serialized_end=10456
  _DESCRIBETOPICRESULT_TOPICSTATS._serialized_start=10459
  _DESCRIBETOPICRESULT_TOPICSTATS._serialized_end=10664
  _DESCRIBECONSUMERREQUEST._serialized_start=10673
  _DESCRIBECONSUMERREQUEST._serialized_end=10812
  _DESCRIBECONSUMERRESPONSE._serialized_start=10814
  _DESCRIBECONSUMERRESPONSE._serialized_end=10886
  _DESCRIBECONSUMERRESULT._serialized_start=10889
  _DESCRIBECONSUMERRESULT._serialized_end=11751
  _DESCRIBECONSUMERRESULT_PARTITIONINFO._serialized_start=11057
  _DESCRIBECONSUMERRESULT_PARTITIONINFO._serialized_end=11313
  _DESCRIBECONSUMERRESULT_PARTITIONCONSUMERSTATS._serialized_start=11316
  _DESCRIBECONSUMERRESULT_PARTITIONCONSUMERSTATS._serialized_end=11751
  _PARTITIONSTATS._serialized_start=11754
  _PARTITIONSTATS._serialized_end=12038
  _ALTERTOPICREQUEST._serialized_start=12041
  _ALTERTOPICREQUEST._serialized_end=12944
  _ALTERTOPICREQUEST_ALTERATTRIBUTESENTRY._serialized_start=8321
  _ALTERTOPICREQUEST_ALTERATTRIBUTESENTRY._serialized_end=8375
  _ALTERTOPICRESPONSE._serialized_start=12946
  _ALTERTOPICRESPONSE._serialized_end=13012
  _ALTERTOPICRESULT._serialized_start=13014
  _ALTERTOPICRESULT._serialized_end=13032
  _DROPTOPICREQUEST._serialized_start=13034
  _DROPTOPICREQUEST._serialized_end=13125
  _DROPTOPICRESPONSE._serialized_start=13127
  _DROPTOPICRESPONSE._serialized_end=13192
  _DROPTOPICRESULT._serialized_start=13194
  _DROPTOPICRESULT._serialized_end=13211
# @@protoc_insertion_point(module_scope)
